##  Overview
Effective cost management is important if financial performance is part of your IT strategy. SAP LeanIX offers cost data fields and report options focused on enterprise architecture. This enables you to gain insights into:
  * [Project Cost](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759840a7a441014b9b08e71b843f53b__section_sqx_v5k_dhc)
  * [Application Cost](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759840a7a441014b9b08e71b843f53b__section_am2_1cl_dhc)
  * [Infrastructure Cost](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759840a7a441014b9b08e71b843f53b__section_tyb_q3l_dhc)


**Note**
SAP LeanIX provides several ways to manage costs related to applications, projects, and IT components. However, it is not a cost management tool. The objective is not to achieve total accuracy in costs within SAP LeanIX. The goal is to establish a level that is easy to maintain for enterprise architecture tasks while meaningful at the same time.
